==> slider_layouts-1.0.8.tar.gz: slider_layouts/src/Plugin/Layout/SliderLayout.php <==
<?php

namespace Drupal\slider_layouts\Plugin\Layout;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;
use Drupal\Core\Plugin\PluginFormInterface;

class SliderLayout extends LayoutDefault implements PluginFormInterface {

  /**
   * Static count value for how many slider sections there are on the page.
   *
   * @var int
   */
  static protected $slider_section_count = 0;

  /**
   * Unique id value for slider section.
   *
   * @var int
   */
  protected $slider_section_id;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    // Set section id and increment static count.
    $this->slider_section_id = self::$slider_section_count++;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      // Default value for slick settings textarea.
      'slick_settings' => "{
  slidesToShow: 1,
  slidesToScroll: 1,
  dots: false,
  arrows: true,
  infinite: true,
  speed: 700,
  autoplay: false
}",
      'shuffle' => FALSE,
      'use_intro_text' => FALSE,
      'intro' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    // Checkbox whether or not to add intro text at the top of the section.
    $form['use_intro_text'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display text at the top of the section'),
      '#default_value' => $this->configuration['use_intro_text'] ?? FALSE,
    ];

    // Optional intro text field.
    $form['intro'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Intro'),
      '#format' => $this->configuration['intro']['format'] ?? 'full_html',
      '#default_value' => $this->configuration['intro']['value'] ?? NULL,
      '#states'   => [
        'visible' => [
          ':input[name="layout_settings[use_intro_text]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    //  Slick settings textarea form element.
    $form['slick_settings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Slick settings'),
      '#default_value' => $this->configuration['slick_settings'],
      '#description' => $this->t('Settings to pass into slick slider, structured like a JavaScript Object. Settings details can be found here <a href="https://github.com/kenwheeler/slick">https://github.com/kenwheeler/slick</a>.'),
      '#rows' => 10,
    ];

    $form['shuffle'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Shuffle?'),
      '#default_value' => $this->configuration['shuffle'],
      '#description' => $this->t('Whether or not to shuffle slide order.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);

    // Convert text to JSON.
    $slick_settings = $this->convertTextToJson($form_state->getValue('slick_settings'));
    $slick_settings = json_decode($slick_settings);

    // Check if JSON is valid, throw error if not.
    if (is_null($slick_settings)) {
      $form_state->setErrorByName('slick_settings', $this->t('Slick settings field has invalid structure. Please use valid JSON.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);

    // Save config values.
    $this->configuration['intro'] = $form_state->getValue('intro');
    $this->configuration['use_intro_text'] = $form_state->getValue('use_intro_text');
    $this->configuration['slick_settings'] = $form_state->getValue('slick_settings');
    $this->configuration['shuffle'] = $form_state->getValue('shuffle');
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);

    // Render the text_format field.
    if ($this->configuration['use_intro_text'] && !empty($this->configuration['intro']['value'])) {
      $build['intro'] = [
        '#type' => 'processed_text',
        '#text' => $this->configuration['intro']['value'],
        '#format' => $this->configuration['intro']['format'],
      ];
    }

    // Add a class with slider section id.
    $build['#attributes']['class'] = [
      'slider-section-id-' . $this->slider_section_id,
    ];

    // Pass config to JavaScript.
    $build['#attached']['drupalSettings']['sliderSection'][$this->slider_section_id] = [
      'slickSettings' => $this->convertTextToJson($this->configuration['slick_settings']),
      'shuffle' => $this->configuration['shuffle'],
    ];

    return $build;
  }

  /**
   * Converts text from a textarea field to JSON format.
   *
   * @param string $text
   *   Text string from textarea form element.
   *
   * @return string
   *   Text converted to JSON format.
   */
  protected function convertTextToJson($text) {
    // Remove whitespace.
    $text = preg_replace('/\s+/', '', $text);
    // Add quotes to property name if it doesn't exist.
    return preg_replace('/([\'"])?([a-z0-9A-Z_]+)([\'"])?:/', '"$2": ', $text);
  }
}

==> slider_layouts-1.0.9.tar.gz: slider_layouts/src/Plugin/Layout/SliderLayout.php <==
<?php

namespace Drupal\slider_layouts\Plugin\Layout;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * Slider Layout plugin.
 */
class SliderLayout extends LayoutDefault implements PluginFormInterface {

  /**
   * Static count value for how many slider sections there are on the page.
   *
   * @var int
   */
  protected static $sliderSectionCount = 0;

  /**
   * Unique id value for slider section.
   *
   * @var int
   */
  protected $sliderSectionId;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    // Set section id and increment static count.
    $this->sliderSectionId = self::$sliderSectionCount++;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      // Default value for slick settings textarea.
      'slick_settings' => "{
  slidesToShow: 1,
  slidesToScroll: 1,
  dots: false,
  arrows: true,
  infinite: true,
  speed: 700,
  autoplay: false
}",
      'shuffle' => FALSE,
      'use_intro_text' => FALSE,
      'intro' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    // Checkbox whether or not to add intro text at the top of the section.
    $form['use_intro_text'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display text at the top of the section'),
      '#default_value' => $this->configuration['use_intro_text'] ?? FALSE,
    ];

    // Optional intro text field.
    $form['intro'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Intro'),
      '#format' => $this->configuration['intro']['format'] ?? 'full_html',
      '#default_value' => $this->configuration['intro']['value'] ?? NULL,
      '#states'   => [
        'visible' => [
          ':input[name="layout_settings[use_intro_text]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    // Slick settings textarea form element.
    $form['slick_settings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Slick settings'),
      '#default_value' => $this->configuration['slick_settings'],
      '#description' => $this->t('Settings to pass into slick slider, structured like a JavaScript Object. Settings details can be found here <a href="https://github.com/kenwheeler/slick">https://github.com/kenwheeler/slick</a>.'),
      '#rows' => 10,
    ];

    $form['shuffle'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Shuffle?'),
      '#default_value' => $this->configuration['shuffle'],
      '#description' => $this->t('Whether or not to shuffle slide order.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);

    // Convert text to JSON.
    $slick_settings = $this->convertTextToJson($form_state->getValue('slick_settings'));
    $slick_settings = json_decode($slick_settings);

    // Check if JSON is valid, throw error if not.
    if (is_null($slick_settings)) {
      $form_state->setErrorByName('slick_settings', $this->t('Slick settings field has invalid structure. Please use valid JSON.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);

    // Save config values.
    $this->configuration['intro'] = $form_state->getValue('intro');
    $this->configuration['use_intro_text'] = $form_state->getValue('use_intro_text');
    $this->configuration['slick_settings'] = $form_state->getValue('slick_settings');
    $this->configuration['shuffle'] = $form_state->getValue('shuffle');
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);

    // Render the text_format field.
    if ($this->configuration['use_intro_text'] && !empty($this->configuration['intro']['value'])) {
      $build['intro'] = [
        '#type' => 'processed_text',
        '#text' => $this->configuration['intro']['value'],
        '#format' => $this->configuration['intro']['format'],
      ];
    }

    // Add a class with slider section id.
    $build['#attributes']['class'] = [
      'slider-section-id-' . $this->sliderSectionId,
    ];

    // Pass config to JavaScript.
    $build['#attached']['drupalSettings']['sliderSection'][$this->sliderSectionId] = [
      'slickSettings' => $this->convertTextToJson($this->configuration['slick_settings']),
      'shuffle' => $this->configuration['shuffle'],
    ];

    return $build;
  }

  /**
   * Converts text from a textarea field to JSON format.
   *
   * @param string $text
   *   Text string from textarea form element.
   *
   * @return string
   *   Text converted to JSON format.
   */
  protected function convertTextToJson($text) {
    // Remove whitespace.
    $text = preg_replace('/\s+/', '', $text);
    // Add quotes to property name if it doesn't exist.
    return preg_replace('/([\'"])?([a-z0-9A-Z_]+)([\'"])?:/', '"$2": ', $text);
  }

}
